withLightness method
Returns a copy of this color with the lightness parameter replaced with
the given value.
Implementation
@override
HSLColour withLightness(double lightness) {
return HSLColour.fromAHSL(alpha, hue, saturation, lightness);
}
Returns a copy of this color with the lightness parameter replaced with
the given value.
@override
HSLColour withLightness(double lightness) {
return HSLColour.fromAHSL(alpha, hue, saturation, lightness);
}