withSaturation method
Returns a copy of this color with the saturation parameter replaced with
the given value.
Implementation
@override
HSVColour withSaturation(double saturation) {
return HSVColour.fromAHSV(alpha, hue, saturation, value);
}
Returns a copy of this color with the saturation parameter replaced with
the given value.
@override
HSVColour withSaturation(double saturation) {
return HSVColour.fromAHSV(alpha, hue, saturation, value);
}