HueRingPainter class

Paints the hue ring for HueRingPicker.

Draws a circular stroke using a SweepGradient that cycles through all 360 degrees of hue. A thumb (white circle with optional colour fill) is positioned at the angle corresponding to the current hsvColor.hue.

The strokeWidth controls the thickness of the ring. Hit testing limits interaction to the annular region between 70% and 130% of the radius, so taps in the centre or far outside the ring are ignored.

Inheritance

Constructors

HueRingPainter(HSVColour hsvColor, {bool displayThumbColor = true, double strokeWidth = 5})
const

Properties

displayThumbColor bool
final
hashCode int
The hash code for this object.
no setterinherited
hsvColor HSVColour
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
strokeWidth double
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) bool
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited