SliderLayout class
Layout delegate for the ColourPickerSlider widget.
Positions three child elements within a slider:
- track — the colour gradient bar, inset 15px from each side.
- thumb — the draggable indicator, overlaid on top of the track.
- gestureContainer — a full-size hit region that captures pan gestures.
The track height is 1/5 of the available height and is vertically centred at 40% of the height. The thumb is sized at 5px wide and 1/4 of the height.
- Inheritance
-
- Object
- MultiChildLayoutDelegate
- SliderLayout
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSize(
BoxConstraints constraints) → Size -
Override this method to return the size of this object given the
incoming constraints.
inherited
-
hasChild(
Object childId) → bool -
True if a non-null LayoutChild was provided for the specified id.
inherited
-
layoutChild(
Object childId, BoxConstraints constraints) → Size -
Ask the child to update its layout within the limits specified by
the constraints parameter. The child's size is returned.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performLayout(
Size size) → void -
Override this method to lay out and position all children given this
widget's size.
override
-
positionChild(
Object childId, Offset offset) → void -
Specify the child's origin relative to this origin.
inherited
-
shouldRelayout(
covariant SliderLayout oldDelegate) → bool -
Override this method to return true when the children need to be
laid out.
override
-
toString(
) → String -
Override this method to include additional information in the
debugging data printed by debugDumpRenderTree and friends.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited